@@ -1,5 +1,5 @@
 import math
-from elasticsearch import Elasticsearch
+from elasticsearch import Elasticsearch, helpers
 
 from politylink.elasticsearch import ELASTICSEARCH_URL
 from politylink.elasticsearch.schema import AbstractText, to_cls
@@ -28,6 +28,17 @@ class ElasticsearchClient:
         except Exception as e:
             raise ElasticsearchException(f'failed to index {obj}') from e
 
+    def bulk_index(self, objects):
+        def actions():
+            for obj in objects:
+                assert isinstance(obj, AbstractText)
+                yield {'_index': obj.index, '_id': obj.id, '_source': obj.__dict__}
+
+        try:
+            return helpers.bulk(client=self.client, actions=actions())
+        except Exception as e:
+            raise ElasticsearchException(f'failed to bulk index') from e
+
     def get(self, id_):
         """
         get a document by politylink id (ref idgen)
