@@ -5,5 +5,8 @@ python3 -m sgqlc.introspection \
      --exclude-description \
      http://localhost:4000 \
      schema.json
+echo "generated schema.json"
 sgqlc-codegen schema.json schema.py
-rm schema.json
\ No newline at end of file
+echo "generated schema.py"
+rm schema.json
+echo "removed schema.json"
\ No newline at end of file
